Don't Hang Up Faux Suede Shirt Dress – Villari Chic
Description: Upgrade your wardrobe with our Don't Hang Up Faux Suede Shirt Dress. Experience the luxurious, super soft faux suede feel while looking effortlessly stylish with the collared neckline and chest pockets. The cuffed sleeves and button front add a touch of sophistication to this comfortable, tiered dress. Faux Suede Colla

Skip to content

FREE SHIPPING On Orders $150+

- Login
- Cart
  0

# Don't Hang Up Faux Suede Shirt Dress

Regular Price
  $59.95

Sale Price
  $59.95
Regular Price

Sale Sold Out

Unit Price
  /per

$59.95

Size: Medium

Small
Medium
Large
1XL
2XL
3XL
Quantity
Added to Cart View Cart or Continue Shopping.
Cart ErrorSome items became unavailable. Update the quantity and try again.

Upgrade your wardrobe with our Don't Hang Up Faux Suede Shirt Dress. Experience the luxurious, super soft faux suede feel while looking effortlessly stylish with the collared neckline and chest pockets. The cuffed sleeves and button front add a touch of sophistication to this comfortable, tiered dress.

- Faux Suede
- Collared Neckline
- Chest Pockets
- Tacked Sleeve Cuff
- Tiered Skirt
- Functional Buttons
- 85% Polyester, 15% Spandex
- True to Size

S: Chest 38" Length 33"
M: Chest 40" Length 34"
L: Chest 42" Length 34"
1XL: Chest 46" Length 38"
2XL: Chest 50" Length 38"
3XL: Chest 54" Length 38"

Model Sabrina is wearing size S

Suggested Pairings:

- Bite Me Bootie in Gold

### Unlock 10% off

When you subscribe to our email list! We'll send you birthday treats, special offers, updates and more!

Email Address

*By completing this form you're signing up to receive our emails and can unsubscribe at any time.